django_kubernetes_manager.migrations package — Django Kubernetes Manager 0.1.0 documentation

# django_kubernetes_manager.migrations package

## Submodules

## django_kubernetes_manager.migrations.0001_initial module

class `django_kubernetes_manager.migrations.0001_initial.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = []
  `initial` = True
  `operations` = [<CreateModel name='KubernetesContainer', fields=[('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('id', <django.db.models.fields.UUIDField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>), ('deployed', <django.db.models.fields.DateTimeField>), ('deleted', <django.db.models.fields.DateTimeField>), ('image_name', <django.db.models.fields.CharField>), ('image_tag', <django.db.models.fields.CharField>), ('image_pull_policy', <django.db.models.fields.CharField>), ('command', <django.db.models.fields.TextField>), ('args', <django.db.models.fields.TextField>), ('port', <django.db.models.fields.IntegerField>)], options={'abstract': False}>, <CreateModel name='TargetCluster', fields=[('id', <django.db.models.fields.AutoField>), ('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('api_endpoint', <django.db.models.fields.URLField>), ('telemetry_endpoint', <django.db.models.fields.URLField>), ('telemetry_source', <django.db.models.fields.CharField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>)], options={'abstract': False}>, <CreateModel name='KubernetesVolumeMount', fields=[('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('id', <django.db.models.fields.UUIDField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>), ('deployed', <django.db.models.fields.DateTimeField>), ('deleted', <django.db.models.fields.DateTimeField>), ('mount_path', <django.db.models.fields.CharField>), ('sub_path', <django.db.models.fields.CharField>), ('cluster', <django.db.models.fields.related.ForeignKey>)], options={'abstract': False}>, <CreateModel name='KubernetesVolume', fields=[('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('id', <django.db.models.fields.UUIDField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>), ('deployed', <django.db.models.fields.DateTimeField>), ('deleted', <django.db.models.fields.DateTimeField>), ('cluster', <django.db.models.fields.related.ForeignKey>)], options={'abstract': False}>, <CreateModel name='KubernetesService', fields=[('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('id', <django.db.models.fields.UUIDField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>), ('deployed', <django.db.models.fields.DateTimeField>), ('deleted', <django.db.models.fields.DateTimeField>), ('labels', <django.contrib.postgres.fields.jsonb.JSONField>), ('annotations', <django.contrib.postgres.fields.jsonb.JSONField>), ('api_version', <django.db.models.fields.CharField>), ('kind', <django.db.models.fields.CharField>), ('port', <django.db.models.fields.IntegerField>), ('namespace', <django.db.models.fields.CharField>), ('kuid', <django.db.models.fields.CharField>), ('selector', <django.contrib.postgres.fields.jsonb.JSONField>), ('target_port', <django.db.models.fields.IntegerField>), ('cluster', <django.db.models.fields.related.ForeignKey>)], options={'abstract': False}>, <CreateModel name='KubernetesPodTemplate', fields=[('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('id', <django.db.models.fields.UUIDField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>), ('deployed', <django.db.models.fields.DateTimeField>), ('deleted', <django.db.models.fields.DateTimeField>), ('labels', <django.contrib.postgres.fields.jsonb.JSONField>), ('annotations', <django.contrib.postgres.fields.jsonb.JSONField>), ('restart_policy', <django.db.models.fields.CharField>), ('cluster', <django.db.models.fields.related.ForeignKey>), ('primary_container', <django.db.models.fields.related.ForeignKey>), ('secondary_container', <django.db.models.fields.related.ForeignKey>), ('volume', <django.db.models.fields.related.ForeignKey>)], options={'abstract': False}>, <CreateModel name='KubernetesNamespace', fields=[('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('id', <django.db.models.fields.UUIDField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>), ('deployed', <django.db.models.fields.DateTimeField>), ('deleted', <django.db.models.fields.DateTimeField>), ('labels', <django.contrib.postgres.fields.jsonb.JSONField>), ('annotations', <django.contrib.postgres.fields.jsonb.JSONField>), ('api_version', <django.db.models.fields.CharField>), ('kind', <django.db.models.fields.CharField>), ('exists', <django.db.models.fields.BooleanField>), ('cluster', <django.db.models.fields.related.ForeignKey>)], options={'abstract': False}>, <CreateModel name='KubernetesJob', fields=[('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('object_status', <django.db.models.fields.CharField>), ('average_cpu_usage', <django.db.models.fields.DecimalField>), ('average_mem_usage', <django.db.models.fields.IntegerField>), ('cpu_usage_seconds', <django.db.models.fields.DecimalField>), ('mem_usage_seconds', <django.db.models.fields.IntegerField>), ('id', <django.db.models.fields.UUIDField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>), ('deployed', <django.db.models.fields.DateTimeField>), ('deleted', <django.db.models.fields.DateTimeField>), ('labels', <django.contrib.postgres.fields.jsonb.JSONField>), ('annotations', <django.contrib.postgres.fields.jsonb.JSONField>), ('api_version', <django.db.models.fields.CharField>), ('kind', <django.db.models.fields.CharField>), ('port', <django.db.models.fields.IntegerField>), ('namespace', <django.db.models.fields.CharField>), ('kuid', <django.db.models.fields.CharField>), ('backoff_limit', <django.db.models.fields.IntegerField>), ('cluster', <django.db.models.fields.related.ForeignKey>), ('pod_template', <django.db.models.fields.related.ForeignKey>)], options={'abstract': False}>, <CreateModel name='KubernetesIngress', fields=[('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('id', <django.db.models.fields.UUIDField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>), ('deployed', <django.db.models.fields.DateTimeField>), ('deleted', <django.db.models.fields.DateTimeField>), ('labels', <django.contrib.postgres.fields.jsonb.JSONField>), ('annotations', <django.contrib.postgres.fields.jsonb.JSONField>), ('api_version', <django.db.models.fields.CharField>), ('kind', <django.db.models.fields.CharField>), ('port', <django.db.models.fields.IntegerField>), ('namespace', <django.db.models.fields.CharField>), ('kuid', <django.db.models.fields.CharField>), ('hostname', <django.db.models.fields.CharField>), ('path', <django.db.models.fields.CharField>), ('cluster', <django.db.models.fields.related.ForeignKey>), ('target_service', <django.db.models.fields.related.ForeignKey>)], options={'abstract': False}>, <CreateModel name='KubernetesDeployment', fields=[('title', <django.db.models.fields.CharField>), ('description', <django.db.models.fields.TextField>), ('slug', <django_extensions.db.fields.AutoSlugField>), ('object_status', <django.db.models.fields.CharField>), ('average_cpu_usage', <django.db.models.fields.DecimalField>), ('average_mem_usage', <django.db.models.fields.IntegerField>), ('cpu_usage_seconds', <django.db.models.fields.DecimalField>), ('mem_usage_seconds', <django.db.models.fields.IntegerField>), ('id', <django.db.models.fields.UUIDField>), ('config', <django.contrib.postgres.fields.jsonb.JSONField>), ('deployed', <django.db.models.fields.DateTimeField>), ('deleted', <django.db.models.fields.DateTimeField>), ('labels', <django.contrib.postgres.fields.jsonb.JSONField>), ('annotations', <django.contrib.postgres.fields.jsonb.JSONField>), ('api_version', <django.db.models.fields.CharField>), ('kind', <django.db.models.fields.CharField>), ('port', <django.db.models.fields.IntegerField>), ('namespace', <django.db.models.fields.CharField>), ('kuid', <django.db.models.fields.CharField>), ('selector', <django.contrib.postgres.fields.jsonb.JSONField>), ('replicas', <django.db.models.fields.IntegerField>), ('cluster', <django.db.models.fields.related.ForeignKey>), ('pod_template', <django.db.models.fields.related.ForeignKey>)], options={'abstract': False}>, <AddField model_name='kubernetescontainer', name='cluster', field=<django.db.models.fields.related.ForeignKey>>, <AddField model_name='kubernetescontainer', name='volume_mount', field=<django.db.models.fields.related.ForeignKey>>]

## Module contents